<?php
namespace Inti\Wp\Middleware;

use Doctrine\DBAL\Connection;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class WpDb
 *
 * @package Inti\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WpDb implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if ((!$request->getAttribute('did_init', false))) {
            /** @var Connection $db */
            $db = $request->getAttribute('db');
            $this->initDb($db);
        }

        return $handler->handle($request);
    }

    private function initDb(Connection $db)
    {
        $config = $db->getParams();

        define('DB_NAME', $config['dbname']);
        define('DB_USER', $config['user']);
        define('DB_PASSWORD', $config['password']);
        define('DB_HOST', $config['host']);
        define('DB_CHARSET', 'utf8mb4');
        define('DB_COLLATE', 'utf8mb4_croatian_ci');

        /**
         * @global wpdb $wpdb WordPress database abstraction object.
         * @since 0.71
         */
        /** @noinspection PhpUnusedLocalVariableInspection */
        global $wpdb;
        // Include the wpdb class and, if present, a db.php database drop-in.
        require_wp_db();

        // Set the database table prefix and the format specifiers for database table columns.
        $GLOBALS['table_prefix'] = 'wp_';
        wp_set_wpdb_vars();
    }
}
